
# Slot: imported_from


the imports entry that this element was derived from.  Empty means primary source

URI: [meta:imported_from](https://w3id.org/biolink/biolinkml/meta/imported_from)

## Domain and Range

[Element](Element.md) ->  <sub>OPT</sub> [String](String.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
